@@ -548,6 +548,3 @@ pub use self::vsphere_virtual_disk_volume_source::VsphereVirtualDiskVolumeSource
 
 mod weighted_pod_affinity_term;
 pub use self::weighted_pod_affinity_term::WeightedPodAffinityTerm;
-
-mod windows_security_context_options;
-pub use self::windows_security_context_options::WindowsSecurityContextOptions;
