@@ -26,6 +26,3 @@ pub use self::job_status::JobStatus;
 
 mod job_template_spec;
 pub use self::job_template_spec::JobTemplateSpec;
-
-mod uncounted_terminated_pods;
-pub use self::uncounted_terminated_pods::UncountedTerminatedPods;
